@@ -16,7 +16,7 @@ from .retry import zyte_api_retrying
 from ..apikey import get_apikey
 from ..constants import API_URL, API_TIMEOUT
 from ..stats import AggStats, ResponseStats
-from ..utils import user_agent
+from ..utils import _process_query, user_agent
 
 
 # 120 seconds is probably too long, but we are concerned about the case with
@@ -49,11 +49,13 @@ class AsyncClient:
                  api_key=None,
                  api_url=API_URL,
                  n_conn=15,
+                 retrying: Optional[AsyncRetrying] = None,
                  ):
         self.api_key = get_apikey(api_key)
         self.api_url = api_url
         self.n_conn = n_conn
         self.agg_stats = AggStats()
+        self.retrying = retrying or zyte_api_retrying
 
     async def request_raw(self, query: dict, *,
                           endpoint: str = 'extract',
@@ -61,7 +63,7 @@ class AsyncClient:
                           handle_retries=True,
                           retrying: Optional[AsyncRetrying] = None,
                           ):
-        retrying = retrying or zyte_api_retrying
+        retrying = retrying or self.retrying
         post = _post_func(session)
         auth = aiohttp.BasicAuth(self.api_key)
         headers = {'User-Agent': user_agent(aiohttp), 'Accept-Encoding': 'br'}
@@ -75,7 +77,7 @@ class AsyncClient:
 
             post_kwargs = dict(
                 url=self.api_url + endpoint,
-                json=query,
+                json=_process_query(query),
                 auth=auth,
                 headers=headers,
             )
